====================================================================
``psyclone.domain.common.transformations.raise_call_2_invoke_trans``
====================================================================

.. automodule:: psyclone.domain.common.transformations.raise_call_2_invoke_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.common.transformations.raise_call_2_invoke_trans


Classes
=======

- :py:class:`RaiseCall2InvokeTrans`:
  Transform a generic PSyIR representation of an Algorithm-layer


.. autoclass:: RaiseCall2InvokeTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: RaiseCall2InvokeTrans
      :parts: 1
